# transfersh-cli

Fork for [unoficial tranfersh python client](https://github.com/tanrax/transfersh-cli) with configuration and extra features.

## Install

``` bash
pip3 install transfersh-cli-config
```

## Use

``` bash
trasnfersh push [file]
```

Example

``` bash
trasnfersh push photos.zip
```

Output

``` bash
Uploading file
Download from here: https://transfer.sh/uDRFQ/upload_file
It has also been copied to the clipboard!
```

In addition, the route will be saved in your clipboard. Ready to paste it where you want :wink:
